@@ -324,7 +324,7 @@ public:
 
     void recoverDeadLetters();
     void closeAllKMailWindows();
-    void cleanup(void);
+    void cleanup();
     void quit();
     bool doSessionManagement();
     bool firstInstance() const;
